#
# spec file for package libunicap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _use_internal_dependency_generator 0
%{expand:%%define prev__find_provides %{__find_provides}}
%define __find_provides sh %{SOURCE1} %{prev__find_provides}
%{expand:%%define prev__find_requires %{__find_requires}}
%define __find_requires sh %{SOURCE1} %{prev__find_requires}

Name:           libunicap
Version:        0.9.12
Release:        24.3
Summary:        Library to access different kinds of (video) capture devices
License:        GPL-2.0-or-later
Group:          Hardware/Camera
URL:            http://www.unicap-imaging.org/
Source0:        %{name}-%{version}.tar.bz2
Source1:        libunicap-filter.sh
Source2:        baselibs.conf
# PATCH-FIX-OPENSUSE openSUSE puts the videodev headers somewhere different in 12.1
Patch1:         libunicap-0.9.12-find_videodev.patch
# PATCH-FIX-UPSTREAM uses the reserved keyword "private" https://bugs.launchpad.net/unicap/+bug/656229
Patch2:         libunicap_0912_fixPrivate.patch
# PATCH-FIX-UPSTREAM libunicap-udev.patch bnc726471 https://bugs.launchpad.net/unicap/+bug/959626 sbrabec@suse.cz -- port rules to the new udev
Patch3:         libunicap-udev.patch
Patch4:         unicap-implicit-fortify-decl.patch
# Patches from Fedora:
Patch5:         libunicap-0.9.12-gcc10.patch
Patch8:         libunicap-0.9.12-arraycmp.patch
Patch9:         libunicap-0.9.12-datadirname.patch
Patch10:        libunicap-bz641623.patch
Patch12:        libunicap-0.9.12-memerrs.patch
Patch13:        libunicap-de-encoding.patch
Patch14:        libunicap-gcc14-fix.patch
BuildRequires:  alsa-lib-devel
BuildRequires:  gettext
BuildRequires:  gtk-doc >= 1.4
BuildRequires:  intltool
BuildRequires:  libogg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtheora-devel
BuildRequires:  libvorbis-devel
BuildRequires:  pkgconfig
BuildRequires:  perl(XML::Parser)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libraw1394)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(udev)
%if 0%{?suse_version} >= 1210
BuildRequires:  libv4l-devel >= 0.8.4
%else
BuildRequires:  kernel-devel
BuildRequires:  libv4l-devel
%endif
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d

%description
Unicap provides a uniform interface to video capture devices. It allows
applications to use any supported video capture device via a single API.
The included ucil library provides easy to use functions to render text
and graphic overlays onto video images.

%package -n libunicap2

Summary:        Library to access different kinds of (video) capture devices
Group:          Hardware/Camera
Provides:       unicap = %{version}
Obsoletes:      unicap < %{version}

%description -n libunicap2
Unicap provides a uniform interface to video capture devices. It allows
applications to use any supported video capture device via a single API.
The included ucil library provides easy to use functions to render text
and graphic overlays onto video images.

%package devel

Summary:        Development files for the unicap library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libunicap2 = %{version}

%description devel
This package includes header files and libraries necessary for
developing programs which use the unicap, unicapgtk, and ucil libraries. It
contains the API documentation of the library, too.

%prep
%setup -q -n %{name}-%{version}
%autopatch -p1

%build
mkdir -p m4
autoreconf -fiv
intltoolize --force
%configure --disable-rpath --disable-static --enable-gtk-doc-html=no --enable-libv4l
make %{?_smp_mflags}

%install
%make_install
# Don't install any static .a and libtool .la files
rm -f %{buildroot}%{_libdir}/{,unicap2/cpi/}*.{a,la}

%find_lang unicap

%post   -n libunicap2 -p /sbin/ldconfig

%postun -n libunicap2 -p /sbin/ldconfig

%files -n libunicap2 -f unicap.lang
%defattr(-,root,root)
%doc AUTHORS ChangeLog README
%license COPYING
%{_libdir}/*.so.*
%{_libdir}/unicap2
%{_udevrulesdir}/50-euvccam.rules

%files devel
%defattr(-,root,root)
%{_datadir}/gtk-doc/html/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/unicap

%changelog
* Tue Aug 27 2024 Takashi Iwai <tiwai@suse.com>
- Fix the build errors with gcc14:
  libunicap-gcc14-fix.patch
* Wed Apr 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add libunicap-de-encoding.patch: Fix build with recent gettext:
  the po files must contain valid charset information.
* Fri Jun  5 2020 Dave Plater <davejplater@gmail.com>
- Fix Factory build, add patches from Fedora:
  libunicap-0.9.12-gcc10.patch, libunicap-0.9.12-arraycmp.patch,
  libunicap-0.9.12-datadirname.patch, libunicap-bz641623.patch
  and libunicap-0.9.12-memerrs.patch
* Thu Sep 28 2017 davejplater@gmail.com
- Fix Factory build by disable gtk-doc html build due to
  gtkdoc-mktmpl having been removed.
* Mon Apr 13 2015 dimstar@opensuse.org
- Call libtoolize during build phase: after running autoreconf,
  we get the new macros installed but do not take into account that
  there was a minor change between intltool 0.50 and 0.51.
* Wed Oct  1 2014 crrodriguez@opensuse.org
- Remove x11 libs buildrequires, never directly linked.
* Thu May  2 2013 crrodriguez@opensuse.org
- While we are at this, place the udev rules in the
  correct localtion (extends libunicap-udev.patch)
* Thu May  2 2013 crrodriguez@opensuse.org
- Fix build with new automake
* Thu Nov 22 2012 crrodriguez@opensuse.org
- Fix implicit declarations rpmlint warning/errors.
- Fix build Requires.
* Fri Mar 16 2012 sbrabec@suse.cz
- Port rules to the new udev (bnc#726471).
* Fri Oct 14 2011 andrea.turrini@gmail.com
- Fixed typos in libunicap.spec
* Tue Oct 11 2011 toddrme2178@gmail.com
- Add a patch to not used the reserved keyword "private".  This
  prevents C++ programs from building against this library
  See: https://bugs.launchpad.net/unicap/+bug/656229
    https://bugs.launchpad.net/unicap/+bug/658739
- Removed deprecated %%clean macro
- Did some trivial spec file cleanups
* Tue Aug 23 2011 toddrme2178@gmail.com
- Fixed typos in spec file that was causing a build error
- Added -32bit compatibility package.  This will be needed
  by some packages using this library.
* Thu Aug 18 2011 toddrme2178@gmail.com
- Renamed package to libunicap per request from Factory
- Cleaned up spec file formatting with spec-cleaner
- Added copyright at the beginning of the spec file
* Wed Aug  3 2011 toddrme2178@gmail.com
- Update to 0.9.12
- Modify .spec file and dependencies for openSUSE
- Switch to .changes file
- Find duplicate files (fix for rpmlint warning)
- Fix groups (fix for rpmlint warning)
- Add patch to fix detection of videodev header in openSUSE 12.1+
* Sat Feb 21 2009 Anas Nashif <anas.nashif@intel.com>
- Initial import into Moblin
* Mon Oct 13 2008 Robert Scheck <robert@fedoraproject.org>
- Upgrade to 0.9.3 (#466825, thanks to Hans de Goede)
- Enabled libv4l support for the new gspca kernel driver
* Sat Aug  9 2008 Robert Scheck <robert@fedoraproject.org>
- Rebuild to get missing dependencies back (#443015, #458527)
* Tue Aug  5 2008 Robert Scheck <robert@fedoraproject.org>
- Filter the unicap plugins which overlap with libv4l libraries
* Tue Jul 22 2008 Robert Scheck <robert@fedoraproject.org>
- Rebuild for libraw1394 2.0.0
* Mon May 19 2008 Robert Scheck <robert@fedoraproject.org>
- Upgrade to 0.2.23
- Corrected packaging of cpi/*.so files (thanks to Arne Caspari)
* Sat May 17 2008 Robert Scheck <robert@fedoraproject.org>
- Upgrade to 0.2.22 (#446021)
* Sat Feb 16 2008 Robert Scheck <robert@fedoraproject.org>
- Added patch to correct libdir paths (thanks to Ralf Corsepius)
* Mon Feb  4 2008 Robert Scheck <robert@fedoraproject.org>
- Changes to match with Fedora Packaging Guidelines (#431381)
* Mon Feb  4 2008 Robert Scheck <robert@fedoraproject.org>
- Upgrade to 0.2.19
- Initial spec file for Fedora and Red Hat Enterprise Linux
